==> haskell-deriving-aeson-0.2.10-123.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-deriving-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deriving-aeson
version:              0.2.10
visibility:           public
id:                   deriving-aeson-0.2.10-9mRt06kxycsDiiikvSSVIh
key:                  deriving-aeson-0.2.10-9mRt06kxycsDiiikvSSVIh
license:              BSD-3-Clause
copyright:            Copyright (c) 2020 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Type driven generic aeson instance customisation
description:
    This package provides a newtype wrapper with
    FromJSON/ToJSON instances customisable via a phantom type parameter.
    The instances can be rendered to the original type using DerivingVia.

category:             JSON, Generics
abi:                  4566b2d8f255a6412da9220f5062e16c
exposed:              True
exposed-modules:      Deriving.Aeson Deriving.Aeson.Stock
import-dirs:          /usr/lib/ghc-9.6.6/site-local/deriving-aeson-0.2.10
library-dirs:         /usr/lib/ghc-9.6.6/site-local/deriving-aeson-0.2.10
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/deriving-aeson-0.2.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deriving-aeson
hs-libraries:         HSderiving-aeson-0.2.10-9mRt06kxycsDiiikvSSVIh
depends:              aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-deriving-aeson/html/deriving-aeson.haddock

haddock-html:         /usr/share/doc/haskell-deriving-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deriving-aeson-0.2.10-124-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-deriving-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deriving-aeson
version:              0.2.10
visibility:           public
id:                   deriving-aeson-0.2.10-JCdhIrS1nkUB2U5zOKzDtq
key:                  deriving-aeson-0.2.10-JCdhIrS1nkUB2U5zOKzDtq
license:              BSD-3-Clause
copyright:            Copyright (c) 2020 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Type driven generic aeson instance customisation
description:
    This package provides a newtype wrapper with
    FromJSON/ToJSON instances customisable via a phantom type parameter.
    The instances can be rendered to the original type using DerivingVia.

category:             JSON, Generics
abi:                  07a90b7d178c95f3cbc2e91ab466bbc8
exposed:              True
exposed-modules:      Deriving.Aeson Deriving.Aeson.Stock
import-dirs:          /usr/lib/ghc-9.6.6/site-local/deriving-aeson-0.2.10
library-dirs:         /usr/lib/ghc-9.6.6/site-local/deriving-aeson-0.2.10
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/deriving-aeson-0.2.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deriving-aeson
hs-libraries:         HSderiving-aeson-0.2.10-JCdhIrS1nkUB2U5zOKzDtq
depends:              aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-deriving-aeson/html/deriving-aeson.haddock

haddock-html:         /usr/share/doc/haskell-deriving-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
